@@ -295,13 +295,15 @@ class WinOSClient:
         # Log response
         transport_sent = self._get_transport_name(ps)
 
-        # Log ERROR and WARNING
+        # Log ERROR
         msg_err = f'{self.host:<14} | {transport_sent:<3} | Something went wrong!\n\t{parsed.stderr}'
-        if parsed.exited or parsed.stderr:  # Exit code != 0 or stderr contains text
+        if parsed.exited:  # Exit code != 0 or stderr contains text
             self.logger.error(msg_err)
             raise RemoteCommandExecutionError(parsed.stderr)
-        # elif not parsed.exited and parsed.stderr:  # warning detected
-        #     self.logger.warning(msg_err)
+
+        # Log WARNING
+        if parsed.stderr:  # warning detected
+            self.logger.warning(msg_err)
 
         # Log INFO and DEBUG
         out = json.dumps(parsed.stdout, indent=4)
@@ -671,6 +673,22 @@ class WinOSClient:
         result = self.run_ps(cmd)
         return result.ok
 
+    def move_item(self, src: str, dst: str) -> bool:
+        r"""Move file on remote server.
+
+        - Move-Item -Path "{source}" -Destination "{dst_full}" -Force
+
+        https://learn.microsoft.com/en-us/powershell/module/microsoft.powershell.management/move-item?view=powershell-7.2
+
+        Args:
+            src: Source path to copy. d:\zen.txt, d:\dir
+            dst: Destination root directory. e:\zen.txt,, e:\dir1
+        """
+
+        cmd = f'Copy-Item -Path "{src}" -Destination "{dst}" -Force'
+        result = self.run_ps(cmd)
+        return result.ok
+
     def create_directory(self, path: str) -> bool:
         """Create directory on remote server. Directories will be created recursively.
 
